function [simulatedvalue,theoreticalvalue]= AR1
% In this exercise we simulated N paths of a AR(1) process
% X_t = c+ \varphi X_{t-1}+ \varepsilon_t, \varepsilon_t ~ i.i.d.
% N(0,\sigma^2)
tic
%% parameter input
% horizon
T=1;
% sample size
Nsimu=10^5;
Nplot=Nsimu;
% grid points
M=10^3;
% volatility stdnrv = sigma
stdnrv=sqrt(0.2);
c=0.5;
phi=0.6;
AR0= 0.1;
% time step
dt= T/M;

% theoretical value
theoreticalvalue= c/(1-phi);
%% Simulation
AR = [AR0*ones(M,Nplot)];
% the process X^(b)
for i =1:M
    AR(i+1,:)=c+ phi*AR(i,:)+stdnrv.*randn(1,Nplot);
end

%plot the first sample path
timegrid= 0:dt:T;
plot(timegrid,AR(:,1))

%compute simulated value
simulatedvalue= mean(AR(end,:));

%estimated variance
estvar= var(AR(end,:));
% confidence interval using CLT
cfplus=simulatedvalue+1.96*sqrt(estvar/Nsimu);
cfminus=simulatedvalue-1.96*sqrt(estvar/Nsimu);

disp('Exact value:')
disp(theoreticalvalue)
disp('Estimated value: ')
disp(simulatedvalue)
disp('Confidence interval: ')
disp([cfminus,cfplus])
toc