function [simulatedvalue,theoreticalvalue]= compoundpoissonprocess
% In this exercise we simulated 10 paths of compound Poisson process
% X^(c)_t= \sum_{i=1}^N_t Z_i with itensity lambda=2 and Z_i = 1/-1 with
% prob=0.5
tic
%% parameter input
% horizon
T=1;
% sample size
Nplot=10;
Nsimu=10^5;
% grid points
M=10^3;
% intensity
lambda=2;
% expection of e^Z
beta = 0.5*(exp(1)+exp(-1));

% theoretical value
theoreticalvalue= exp(lambda*T*(beta-1));
%% Simulation
% compound poisson process
figure(1)
% method 1
% number of total jumps at T
NT= poissrnd(lambda*T,1,Nplot);
temp1= zeros(max(NT),Nplot);
for i =1:Nplot
    %condition on N_T, the jump times are ordered uniformlly distributed
    temp1(1:NT(i),i)= sort(T*rand(1,NT(i)));
    % simulate Z
    stairs([0;temp1(1:NT(i),i)],cumsum([0,2*unidrnd(2,1,NT(i))-3])')
    hold on;
end
hold off;


% method 2
figure(2)
CPP = [zeros(1,Nplot);cumsum(poissrnd(lambda*T/M,M,Nplot).*(2*unidrnd(2,M,Nplot)-3))];
% the process X^(a)
timegrid= 0:T/M:T;
Xc=CPP;

%show the first 10 sample paths
plot(timegrid,Xc(:,1:10))

%compute simulated value
% the poisson process N
poissonrv=poissrnd(lambda*T,1,Nsimu);
maxN=max(poissonrv);
% the jump distribution Z
bernoullirv= 2*unidrnd(2,maxN,Nsimu)-3;
% place holder
temp= zeros(1,Nsimu);
for i=1:maxN
    % we only consider those numbers for which the poisson process is > 0
    index= (poissonrv>0);
    temp(index)=temp(index)+bernoullirv(i,index);
    poissonrv(index)=poissonrv(index)-1;
end
simulatedvalue= mean(exp(temp));


%estimated variance
estvar= var(exp(temp));
% confidence interval using CLT
cfplus=simulatedvalue+1.96*sqrt(estvar/Nsimu);
cfminus=simulatedvalue-1.96*sqrt(estvar/Nsimu);

disp('Exact value:')
disp(theoreticalvalue)
disp('Estimated value: ')
disp(simulatedvalue)
disp('Confidence interval: ')
disp([cfminus,cfplus])
toc
